<?php
//////////////////////////////////////
// Algemene Functies
//////////////////////////////////////

// Controleren of het bestand rechtstreeks wordt aangeroepen, zoja stop het script.
if (basename($_SERVER['PHP_SELF']) === 'functieskp.php') {
    die('Directe toegang tot dit bestand is niet toegestaan.');
}
// Regel aan logbestand toevoegen
function logFout($fout) {
    $logbestand = 'log.txt';
    $datum = date("d-m-Y H:i");
    $regelToeTeVoegen = "$datum | $fout";
    file_put_contents($logbestand, $regelToeTeVoegen . PHP_EOL, FILE_APPEND);
}
// PDF naar Base64 voor klanten
function getBase64PDF($filePath) {
    if (file_exists($filePath)) {
        $pdfData = file_get_contents($filePath);
        return base64_encode($pdfData);
    } else {
        return false;
    }
}
// Optie Updaten
function updateOptie($optienaam, $waarde) {
    global $connect;
    $query = "UPDATE opties SET waarde=? WHERE naam=?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("ss", $waarde, $optienaam);
        $stmt->execute();
        $stmt->close();
    } else {
        logFout('updateOptie -> prepared statement mislukt');
    }
}
// Betaallink genereren
function maakBetaallink($bedrag, $omschrijving, $kenmerk) {
    if (kiesOptie('ideal_ingeschakeld') == '1') {
        if (kiesOptie('ideal_testmodus') == '1') {
            $api_key = kiesOptie('ideal_test_key');
        } else if (kiesOptie('ideal_testmodus') == '0') {
            $api_key = kiesOptie('ideal_live_key');
        }
        $baseUrl = kiesOptie('site-url');
        $url = 'https://api.mollie.com/v2/payments';
        $data = [
            'amount' => [
                'currency' => 'EUR',
                'value' => $bedrag,
            ],
            'description' => $omschrijving,
            'redirectUrl' => $baseUrl.'/betalen/betaling.php?id='.$kenmerk,
            'webhookUrl' => $baseUrl.'/includes/pay.php',
        ];
        $curl = curl_init($url);
        curl_setopt($curl, CURLOPT_POST, true);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_HTTPHEADER, [
            'Authorization: Bearer ' . $api_key,
            'Content-Type: application/json',
        ]);
        curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($data));
        $response = curl_exec($curl);
        if ($response === false) {
            echo 'Curl error: ' . curl_error($curl);
        } else {
            $payment = json_decode($response, true);
            if(isset($payment['_links']['checkout']['href'])) {
                $payurl = $payment['_links']['checkout']['href'];
            } else {
                $payurl = 'niet beschikbaar';
            }
        }
        curl_close($curl);
        return $payurl;
    } else {
        $payurl = 'niet beschikbaar';
        return $payurl;
    }
}
// Meldingboxen
function melding($type,$koptekst,$subtext) {
    if ($type == 'notice') {
        $icon = 'fa-circle-check';
        $color = '#c1d9b8';
        echo "<script>
        setTimeout(function() {
        $('.meldingwrap').fadeOut('fast');
        }, 3000);
        </script>";
    } else if ($type == 'warning') {
        $icon = 'fa-circle-exclamation';
        $color = '#efe4ac';
    } else if ($type == 'error') {
        $icon = 'fa-circle-xmark';
        $color = '#e6b2ae';
    } else if ($type == 'global') {
        $icon = 'fa-circle-info';
        $color = '#a5d5ee';
        echo "<script>
        setTimeout(function() {
        $('.meldingwrap').fadeOut('fast');
        }, 3000);
        </script>";
    }
    echo '<div class="meldingwrap">
    <p class="'.$type.'box">
    <i class="meldingicon fa-solid '.$icon.'" style="color: '.$color.'; margin-right: 10px;"></i>
    <button class="melding-sluiten" onclick="closeMelding()"><i class="fa-solid fa-xmark"></i></button>
    <b>'.$koptekst.'</b><br>'.$subtext.'
    </p>
    </div>';
}
// Dag Vertalen
function vertaalDag($dag) {
    if ($dag == 'Mon') {
        return 'Maandag';
    } else if ($dag == 'Tue') {
        return 'Dinsdag';
    } else if ($dag == 'Wed') {
        return 'Woensdag';
    } else if ($dag == 'Thu') {
        return 'Donderdag';
    } else if ($dag == 'Fri') {
        return 'Vrijdag';
    } else if ($dag == 'Sat') {
        return 'Zaterdag';
    } else if ($dag == 'Sun') {
        return 'Zondag';
    } else {
        return '';
    }
}
// Optie Inladen (algemeen)
function kiesOptie($optienaam) {
    global $connect;
    $query = "SELECT waarde FROM opties WHERE naam=?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("s", $optienaam);
        $stmt->execute();
        $stmt->bind_result($optie);
        $stmt->fetch();
        $stmt->close();
        return $optie;
    } else {
        logFout('kiesOptie -> prepared statement mislukt');
        return null;
    }
}
// bereken voorrijkosten
function checkVoorrij($postcode) {
    $vertrekpc = kiesOptie('voorrij_postcode');
    $token = kiesOptie('voorrij_token');
    $gratiskm = kiesOptie('voorrij_gratis');
    $kostenperkm = kiesOptie('voorrij_bedrag');
    $url = 'http://dev.virtualearth.net/REST/v1/Routes?waypoint.0='.$postcode.'&waypoint.1='.$vertrekpc.'&&optimize=distance&distanceUnit=km&key='.$token.'';
    $jsonResponse = file_get_contents($url);
    $data = json_decode($jsonResponse, true);
    if (isset($data['resourceSets'][0]['resources'][0]['travelDistance'])) {
        $travelDistance = $data['resourceSets'][0]['resources'][0]['travelDistance'];
        $travelDistanceF = round($travelDistance,0) - $gratiskm;
        if ($travelDistanceF < 1) {
            $voorrijkosten = 'gratis';
            return $voorrijkosten;
        } else if ($travelDistanceF > 0)
            $travelDistanceF2 = $travelDistanceF * $kostenperkm;
            $travelDistanceF1 = number_format($travelDistanceF2,2);
        $voorrijkosten = '€'.$travelDistanceF1;
        return $voorrijkosten;
    } else {
        $voorrijkosten = 'niet bekend';
        return $voorrijkosten;
    }
}
// Check of mail is ingesteld.
function mailReady() {
    if (
        !empty(kiesOptie('smtp_namefrom')) &&
        !empty(kiesOptie('smtp_email')) &&
        !empty(kiesOptie('smtp_host')) &&
        !empty(kiesOptie('smtp_username')) &&
        !empty(kiesOptie('smtp_password')) &&
        !empty(kiesOptie('smtp_auth')) &&
        !empty(kiesOptie('smtp_port')) && 
        (kiesOptie('smtp_ok') === '1')
    ) {
        return 1;
    } else {
        return 0;
    }
}
// Openstaande facturen
function openstaandeFacturen() {
    global $connect;
    $query = "SELECT * FROM facturen WHERE status='12' ORDER BY factuurdatum ASC";
    $result = $connect->query($query);
    if ($result) {
        $facturen = array();
        while ($row = mysqli_fetch_assoc($result)) {
            $facturen[] = $row;
        }
    } else {
        logFout('openstaandeFacturen -> query mislukt');
    }
    return $facturen;
}



//////////////////////////////////////
// Mail Functies
//////////////////////////////////////
use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;
require './includes/smtp/PHPMailer.php';
require './includes/smtp/Exception.php';
require './includes/smtp/SMTP.php';

// Test Verbinding
function testSMTPConnection() {
    $mail = new PHPMailer(true);
    try {
        $pass = base64_decode(kiesOptie('smtp_password'));
        $mail->isSMTP();
        $mail->Host = kiesOptie('smtp_host');
        $mail->SMTPAuth = true;
        $mail->Username = kiesOptie('smtp_username');
        $mail->Password = $pass;
        $mail->SMTPSecure = kiesOptie('smtp_auth');
        $mail->Port = kiesOptie('smtp_port');
        if ($mail->smtpConnect()) {
            return '1';
        } else {
            return '0';
        }
    } catch (Exception $e) {
        return '0';
    }
}
// Loginlink Klantenlogin
function stuurLogin($email) {
    $resultaat = testSMTPConnection();
    if ($resultaat === '1') {
        global $connect;
        $sql = $connect->prepare("SELECT * FROM klanten WHERE email = ?");
        $sql->bind_param("s", $email);
        $sql->execute();
        $result = $sql->get_result();
        if ($result->num_rows > 0) {
            while ($row = $result->fetch_assoc()) {
                $tokentime = date('Y-m-d H:i');
                $length = 20;
                $characters = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_-';
                $randomstring = substr(str_shuffle($characters), 0, $length);
                $updateSql = $connect->prepare("UPDATE klanten SET logintoken = ?, tokentime = ? WHERE email = ?");
                $updateSql->bind_param("sss", $randomstring, $tokentime, $email);
                if ($updateSql->execute()) {
                    $template = getTemplate(kiesOptie('template_login'));
                    $bericht = base64_decode($template['template']);
                    $onderwerp = $template['naam'];
                    $loginlink = kiesOptie('site-url').'/index.php?token='.$randomstring;
                    $bericht = str_replace('{klant_bedrijfsnaam}', $row['bedrijfsnaam'], $bericht);
                    $bericht = str_replace('{klant_voornaam}', $row['naam'], $bericht);
                    $bericht = str_replace('{klant_achternaam}', $row['achternaam'], $bericht);
                    $bericht = str_replace('{loginlink}', '<a href="'.$loginlink.'">Inloggen</a>', $bericht);
                    $mail = new PHPMailer(true);
                    try {
                        $pass = base64_decode(kiesOptie('smtp_password'));
                        $mail->isSMTP();
                        $mail->Host = kiesOptie('smtp_host');
                        $mail->SMTPAuth = true;
                        $mail->Username = kiesOptie('smtp_username');
                        $mail->Password = $pass;
                        $mail->SMTPSecure = kiesOptie('smtp_auth');
                        $mail->Port = kiesOptie('smtp_port');
                        $mail->setFrom(kiesOptie('smtp_email'), kiesOptie('smtp_namefrom'));
                        $mail->addAddress($email);
                        $mail->isHTML(true);
                        $mail->Subject = $onderwerp;
                        $mail->Body = $bericht;
                        $mail->send();
                    } catch (Exception $e) {
                        echo '<div class="errorwrap"><p class="error">Er is iets mis gegaan met het versturen van de e-mail.<br><br><button class="form-button-2" style="font-size:12px; border:0;" type="button" name="niks" onclick="closeMelding()">Sluiten</button></p></div>';
                    }
                } else {
                    echo '<div class="errorwrap"><p class="error">Fout bij het maken van de token.<br><br><button class="form-button-2" style="font-size:12px; border:0;" type="button" name="niks" onclick="closeMelding()">Sluiten</button></p></div>';
                }
            }
        }
    } else {
        updateOptie('smtp_ok', '0');
        echo '<div class="errorwrap"><p class="error">Er is iets mis gegaan met het versturen van de e-mail.<br><br><button class="form-button-2" style="font-size:12px; border:0;" type="button" name="niks" onclick="closeMelding()">Sluiten</button></p></div>';
    }
}
// Enkele Template laden
function getTemplate($tempid) {
    global $connect;
    $query = "SELECT * FROM templates WHERE id=?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("i", $tempid);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result) {
            $template = mysqli_fetch_assoc($result);
            return $template;
        } else {
            echo "Fout bij het uitvoeren van de query: " . mysqli_error($connect);
        }
        $stmt->close();
    }
    return null;
}
// Toon alle afspraken
function alleAfspraken($klantid, $startfrom, $perpage) {
    global $connect;
    global $user_id;
    $query = !empty($klantid) ? "SELECT * FROM afspraken WHERE klantid=? AND status NOT IN ('0') ORDER BY datum DESC, start_tijd DESC LIMIT ?, ?" : "SELECT * FROM afspraken WHERE plannerid=? OR userid=? and status NOT IN ('0') ORDER BY datum DESC, start_tijd DESC LIMIT ?, ?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        if (!empty($klantid)) {
            $stmt->bind_param("iss", $klantid, $startfrom, $perpage);
        } else {
            $stmt->bind_param("iiss", $user_id, $user_id, $startfrom, $perpage);
        }
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result) {
            $afspraken = array();
            while ($row = mysqli_fetch_assoc($result)) {
                $afspraken[] = $row;
            }
        } else {
            echo "Fout bij het uitvoeren van de query: " . mysqli_error($connect);
        }
        $stmt->close();
        return $afspraken;
    } else {
        echo "Fout bij het voorbereiden van de query: " . mysqli_error($connect);
    }
}
// Open enkele afspraak
function getAfspraak($afspraakid) {
    global $connect;
    $query = "SELECT * FROM afspraken WHERE id=?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("i", $afspraakid);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result) {
            $afspraak = mysqli_fetch_assoc($result);
        } else {
            echo "Fout bij het uitvoeren van de query: " . mysqli_error($connect);
        }
        $stmt->close();
        return $afspraak;
    } else {
        echo "Fout bij het voorbereiden van de query: " . mysqli_error($connect);
    }
}



//////////////////////////////////////
// Reparatie Functies
//////////////////////////////////////


// Open enkele reparatie
function getReparatie($repid) {
    global $connect;
    $query = "SELECT * FROM reparaties WHERE id=?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("i", $repid);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result) {
            $afspraak = mysqli_fetch_assoc($result);
        } else {
            echo "Fout bij het uitvoeren van de query: " . mysqli_error($connect);
        }
        $stmt->close();
        return $afspraak;
    } else {
        echo "Fout bij het voorbereiden van de query: " . mysqli_error($connect);
    }
}
// Toon alle reparaties
function alleReparaties($klantid, $startfrom, $perpage) {
    global $connect;
    global $user_id;
    $query = !empty($klantid) ? "SELECT * FROM reparaties WHERE klantid=? ORDER BY id DESC LIMIT ?, ?" : "SELECT * FROM reparaties WHERE userid=? ORDER BY id DESC LIMIT ?, ?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        if (!empty($klantid)) {
            $stmt->bind_param("iss", $klantid, $startfrom, $perpage);
        } else {
            $stmt->bind_param("iss", $user_id, $startfrom, $perpage);
        }
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result) {
            $reparaties = array();
            while ($row = mysqli_fetch_assoc($result)) {
                $reparaties[] = $row;
            }
        } else {
            echo "Fout bij het uitvoeren van de query: " . mysqli_error($connect);
        }
        $stmt->close();
        return $reparaties;
    } else {
        echo "Fout bij het voorbereiden van de query: " . mysqli_error($connect);
    }
}


// Telfunctie voor klantstatus
function offertesTellen($klantid) {
    global $connect;
    $query = "SELECT COUNT(*) as count FROM facturen WHERE klantid=? AND status IN (20,21,22)";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("i", $klantid);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result) {
            $row = $result->fetch_assoc();
            $count = $row['count'];
            if ($count > 0) {
                return $count;
            } else {
                return '0';
            }
        }
        $stmt->close();
    } else {
        echo "Fout bij het voorbereiden van de query: " . mysqli_error($connect);
    }
}
function facturenTellen($klantid) {
    global $connect;
    $query = "SELECT COUNT(*) as count FROM facturen WHERE klantid=? AND status IN (10,11,12)";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("i", $klantid);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result) {
            $row = $result->fetch_assoc();
            $count = $row['count'];
            if ($count > 0) {
                return $count;
            } else {
                return '0';
            }
        }
        $stmt->close();
    } else {
        echo "Fout bij het voorbereiden van de query: " . mysqli_error($connect);
    }
}
function afsprakenTellen($klantid) {
    global $connect;
    $query = "SELECT COUNT(*) as count FROM afspraken WHERE klantid=? AND status IN (1,2)";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("i", $klantid);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result) {
            $row = $result->fetch_assoc();
            $count = $row['count'];
            if ($count > 0) {
                return $count;
            } else {
                return '0';
            }
        }
        $stmt->close();
    } else {
        echo "Fout bij het voorbereiden van de query: " . mysqli_error($connect);
    }
}
function reparatiesTellen($klantid) {
    global $connect;
    $query = "SELECT COUNT(*) as count FROM reparaties WHERE klantid=?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("i", $klantid);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result) {
            $row = $result->fetch_assoc();
            $count = $row['count'];
            if ($count > 0) {
                return $count;
            } else {
                return '0';
            }
        }
        $stmt->close();
    } else {
        echo "Fout bij het voorbereiden van de query: " . mysqli_error($connect);
    }
}
// einde tellen


// Klant wijzigingen opslaan
function klantOpslaan($id, $naam, $achternaam, $bedrijfsnaam, $straat, $postcode, $plaats, $telefoon, $mobiel, $btw, $kvk) {
    global $connect;
    if (empty($achternaam) || empty($straat) || empty($postcode) || empty($plaats)) {
        echo '<div class="errorwrap"><p class="error">Vul alle verplichten velden in.<br><br><button class="form-button-2" style="font-size:12px; border:0;" type="button" name="niks" onclick="closeMelding()">Sluiten</button></p></div>';
        return;
    }
    $query = "UPDATE klanten SET naam=?, achternaam=?, bedrijfsnaam=?, straat=?, postcode=?, woonplaats=?, telefoon=?, mobiel=?, btw=?, kvk=? WHERE id=?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("ssssssssssi", $naam, $achternaam, $bedrijfsnaam, $straat, $postcode, $plaats, $telefoon, $mobiel, $btw, $kvk, $id);
        if ($stmt->execute()) {
            echo '<div class="noticewrap"><p class="notice">Opgeslagen.<br><br><button class="form-button-2" style="font-size:12px; border:0;" type="button" name="niks" onclick="closeMelding2()">Sluiten</button></p></div>';
            $klantid = $connect->insert_id;
            $stmt->close();
            return $klantid;
        } else {
            logFout('klantOpslaan -> query mislukt (opslaan klant)');
            $stmt->close();
            return;
        }
    } else {
        logFout('klantOpslaan -> prepare query mislukt (opslaan klant)');
        return;
    }
}

// Enkele klant tonen
function getKlant($klantid) {
    global $connect;
    $query = "SELECT * FROM klanten WHERE id=?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("i", $klantid);
        $stmt->execute();
        $result = $stmt->get_result();
        $stmt->close();
    } else {
        logFout('getKlant -> query mislukt');    
        return null;
    }
    if ($result) {
        $klant = mysqli_fetch_assoc($result);
    } else {
        logFout('getKlant -> query mislukt');    
        return null;
    }
    return $klant;
}



//////////////////////////////////////
// Facturatie Functies
//////////////////////////////////////


// Offerte Akkoord en Factuur maken (concept)
function offerteAkkoord($factuurid) {
    global $connect;
    $query = "SELECT * FROM facturen WHERE id=?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("i", $factuurid);
        $stmt->execute();
        $result = $stmt->get_result();
        $stmt->close();
    } else {
        logFout('offerteDefinitief -> Geen factuur input');
    }
    if ($result) {
        $factuur = mysqli_fetch_assoc($result);
        $regels = json_decode($factuur['regels'], true);
        $totaalbedrag = $factuur['totaalbedrag'];
        $referentie = 'Offerte: '.$factuur['factuurnummer'];
        $jsonRegels = json_encode($regels);
        $query = "INSERT INTO facturen (klantid, status, regels, factuurdatum, factuurnummer, totaalbedrag, klantgegevens, bedrijfgegevens, catid, betaaldatum, ref, pdf, betaallink, verlegd, kenmerk, payid, herinnering, aanmaning) 
        VALUES (?, '10', ?, '', '', ?, '', '', '', '', ?, '', '', ?, '', '', '0', '0')";
        $stmt = $connect->prepare($query);
        if ($stmt) {
            $stmt->bind_param("issss", $factuur['klantid'], $jsonRegels, $totaalbedrag, $referentie, $factuur['verlegd']);
            if ($stmt->execute()) {
                $datumverwerkt = date('Y-m-d');
                $factuurID = $stmt->insert_id;
                $query = "UPDATE facturen SET status='23', betaaldatum='".$datumverwerkt."' WHERE id=".$factuur['id']."";
                $result = $connect->query($query);
                return $factuurID;
            } 
            $stmt->close();
        } else {
            logFout('offerteAkkoord -> prepared statement credit aanmaken mislukt');
        }
    } else {
        logFout('offerteAkkoord -> geen resultaat');
    }
}
// Offerte Afgewezen
function offerteAfgewezen($factuurid) {
    global $connect;
    $query = "UPDATE facturen SET status='24' WHERE id=?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("i", $factuurid);
        $stmt->execute(); 
        $stmt->close();
    } 
}
// Alle facturen laden (alles of per klant)
function facturenLaden($klantid, $startfrom, $perpage) {
    global $connect;
    if (!empty($klantid)) {
        $query = "SELECT * FROM facturen WHERE klantid=? AND status IN (12,13,14,15) ORDER BY id DESC  LIMIT ?, ?";
        $stmt = $connect->prepare($query);
        if ($stmt) {
            $stmt->bind_param("iss", $klantid, $startfrom, $perpage);
            $stmt->execute();
            $result = $stmt->get_result();
            $stmt->close();
        } else {
            logFout('facturenLaden -> query mislukt');
        }
    } else {
        $query = "SELECT * FROM facturen WHERE status IN (12,13,14,15) ORDER BY id DESC LIMIT $startfrom, $perpage";
        $result = $connect->query($query);
    }
    if ($result) {
        $facturen = array();
        while ($row = mysqli_fetch_assoc($result)) {
            $facturen[] = $row;
        }
    } else {
        logFout('facturenLaden -> query mislukt');
    }
    return $facturen;
}
// Factuur/offerte openen in editor
function openFactuur($factuurid) {
    global $connect;
    $query = "SELECT * FROM facturen WHERE id=?";
    $stmt = $connect->prepare($query);
    if ($stmt) {
        $stmt->bind_param("i", $factuurid);
        $stmt->execute();
        $result = $stmt->get_result();
        $stmt->close();
    } else {
        logFout('openFactuur -> query mislukt');
    }
    if ($result) {
        $factuur = mysqli_fetch_assoc($result);
    } else {
        logFout('openFactuur -> query mislukt');
    }
    return $factuur;
}

// Offertes laden
function offertesLaden($klantid, $startfrom, $perpage) {
    global $connect;
    if (empty($klantid)) {
        $query = "SELECT * FROM facturen WHERE status IN (22, 23, 24) ORDER BY id DESC LIMIT ?, ?";
    } else {
        $query = "SELECT * FROM facturen WHERE klantid=? AND status IN (22, 23, 24) ORDER BY id DESC LIMIT ?, ?";
    }
    $stmt = $connect->prepare($query);
    if ($stmt) {
        if (!empty($klantid)) {
            $stmt->bind_param("iss", $klantid, $startfrom, $perpage);
        } else {
            $stmt->bind_param("ss", $startfrom, $perpage);
        }
        $stmt->execute();
        $result = $stmt->get_result();
        $stmt->close();
        if ($result) {
            $facturen = array();
            while ($row = mysqli_fetch_assoc($result)) {
                $facturen[] = $row;
            }

            return $facturen;
        } else {
            logFout('offertesLaden -> query mislukt');
        }
    } else {
        logFout('offertesLaden -> query mislukt');
    }
    return array();
}
?>